Changelog
=========

(v0.6.0) June 14, 2023
----------------------

Commit `ef005bd <https://github.com/fnpy/fn.py/commit/ef005bdc89aae0494b18792834a1dd47a027036c>`_ by `jacobbridges <https://github.com/jacobbridges>`_ on Jun 14, 2023

- `Pull Request #46 <https://github.com/fnpy/fn.py/pull/46>`_
- Switch from TravisCI to Github Actions


Commit `d8c21ab <https://github.com/fnpy/fn.py/commit/d8c21abef1db3bf558b4d90469483461d4149210>`_ by `artemisart <https://github.com/artemisart>`_ on Apr 25, 2020

- `Pull Request #40 <https://github.com/fnpy/fn.py/pull/40>`_
- Documentation + some fixes


Commit `9958f1f <https://github.com/fnpy/fn.py/commit/9958f1f8678f27239760e17a8866288875519a7e>`_ by `soasme <https://github.com/soasme>`_ on Sep 5, 2019

- `Pull Request #39 <https://github.com/fnpy/fn.py/pull/39>`_
- Import Iterable from collections.abc for >=3.8


Commit `486119e <https://github.com/fnpy/fn.py/commit/486119e4d25892c8a8052826fd392601ad6e4d4e>`_ by `fwfurtado <https://github.com/fwfurtado>`_ on Sep 5, 2019

- `Pull Request #37 <https://github.com/fnpy/fn.py/pull/37>`_
- Added supporting to type hint in curried decorator


Commit `c01c2b7 <https://github.com/fnpy/fn.py/commit/c01c2b7235e0ef8b65a53b91df560c7e01c50027>`_ by `katoken-0215 <https://github.com/katoken-0215>`_ on Mar 24, 2018

- `Pull Request #33 <https://github.com/fnpy/fn.py/pull/33>`_
- Introduce guard for recursive call by doctest.

(v0.5.0) July 17, 2017
----------------------

Commit: `10efa8b <https://github.com/fnpy/fn.py/commit/10efa8b35c327ae77dfb01878451694bd5a47ea9>`_.

- Added ``recur.stackless()`` Provides a "stackless" (constant Python stack space) recursion decorator for generators.
